@@ -1,13 +1,15 @@
 
 package PRANG;
 {
-  $PRANG::VERSION = '0.16';
+  $PRANG::VERSION = '0.17';
 }
 
 1;
 
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 PRANG - XML graph engine - XML to Moose objects and back!
@@ -71,7 +73,7 @@ PRANG - XML graph engine - XML to Moose objects and back!
      </lust>
    </lust>
  </envy>
- XML;
+ XML
 
  # Parsing the above would give you the same structure as this:
  XML::Language->new(
@@ -85,7 +87,8 @@ PRANG - XML graph engine - XML to Moose objects and back!
                  greed => 1,
              ),
          ],
-     );
+     )
+ );
 
  # step 4b.  emit!
  $format = 1;
