@@ -1,7 +1,7 @@
 
 package PRANG::Marshaller;
 {
-  $PRANG::Marshaller::VERSION = '0.16';
+  $PRANG::Marshaller::VERSION = '0.17';
 }
 
 use Moose;
@@ -90,17 +90,48 @@ sub parse {
         filename => { isa => 'Str', optional => 1 },
         fh => { isa => 'GlobRef', optional => 1 },
         lax => { isa => 'Bool', optional => 1, default => 0 },
-    );    
+    );
 
-	my $parser = XML::LibXML->new;
-	my $dom = (
-		defined $xml ? $parser->parse_string($xml) :
-			defined $filename ? $parser->parse_file($filename) :
-			defined $fh ? $parser->parse_fh($fh) :
-			croak("no input passed to parse")
-	);
+    my $parser = XML::LibXML->new;
+    my $dom = (
+        defined $xml ? $parser->parse_string($xml) :
+            defined $filename ? $parser->parse_file($filename) :
+            defined $fh ? $parser->parse_fh($fh) :
+            croak("no input passed to parse")
+    );
+
+    return $self->from_dom(
+        dom => $dom,
+        lax => $lax
+    );
+}
+
+sub from_dom {
+    my $self = shift;
+
+    my ( $dom, $lax ) = validated_list(
+        \@_,
+        dom => { isa => 'XML::LibXML::Document', },
+        lax => { isa => 'Bool', optional => 1, default => 0 },
+    );
 
 	my $rootNode = $dom->documentElement;
+	
+	return $self->from_root_node(
+	   root_node => $rootNode,
+	   lax => $lax,
+	);
+}
+
+sub from_root_node {
+    my $self = shift;
+
+    my ( $rootNode, $lax ) = validated_list(
+        \@_,
+        root_node => { isa => 'XML::LibXML::Node', },
+        lax => { isa => 'Bool', optional => 1, default => 0 },
+    );
+    
 	my $rootNodeNS = $rootNode->namespaceURI;
 
 	my $xsi = {};
